| getCoin | R Documentation |
Download cryptocurrency daily time series from Alpha vantage using either a free or premium API key. Includes open high low close, volume and market cap.
getCoin(
symbol = "BTC",
period = "daily",
interval = NULL,
market = "USD",
datatype = "json",
key = "premium"
)
symbol |
cryptocurrency symbol, i.e. "BTC" (string) |
period |
"daily", "weekly", "monthly", "yearly", or "intraday" |
interval |
NULL for anything but intraday otherwise "1min", "5min", "15min", "30min", "60min" |
market |
physical currency symbol for quoting i.e. "USD", "CNY", etc. |
datatype |
"json" or "csv" for return type to be parsed |
key |
string for the API key to use Alpha Vantage |
xts object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.